/*-----------------------------------------------------------------------

File  : parser.h

Author: Stephan Schulz

Contents
 
  Declarations for use with a simple parser for PL

  Copyright 2002 by the author.
  This code is released under the GNU General Public Licence.
  See the file COPYING.

Changes

<1> Tue Oct  1 23:52:19 CEST 2002
    New

-----------------------------------------------------------------------*/

#ifndef PARSER

#define PARSER

#include "scanner.h"


/*---------------------------------------------------------------------*/
/*                    Data type declarations                           */
/*---------------------------------------------------------------------*/

typedef enum 
{
   StInc,
   StNull,
   StGoto,
   StLoop
}StatementType;


typedef struct statement_cell
{
   long             statement_id; /* Unique identifier */
   StatementType    type;
   char             *label; /* Optional */
   char             *argument; /* Either label for goto or variable */
   struct prog_cell *subprog; /* For loop */
}StatementCell, *Statement_p;

typedef struct prog_cell
{
   Statement_p statement;
   struct prog_cell *prog_rest;
}ProgCell, *Prog_p;


/*---------------------------------------------------------------------*/
/*                Exported Functions and Variables                     */
/*---------------------------------------------------------------------*/

#define INDENT_CHAR 3
extern Token current;

void PrintIndent(int arg);
void PrintStatement(Statement_p statement, int indent);
void PrintProgram(Prog_p prog, int indent);

Statement_p ParseStatement();
Prog_p      ParseProg();

#endif

/*---------------------------------------------------------------------*/
/*                        End of File                                  */
/*---------------------------------------------------------------------*/

